@@ -114,15 +114,15 @@ atome lesatomes[] ={
 {107, "Bh"},
 {108, "Hs"},
 {109, "Mt"},
-{110, "Uun"},
-{111, "Uuu"},
-{112, "Uub"},
-{113, "Uut"},
-{114, "Uuq"},
-{115, "Uup"},
-{116, "Uuh"},
-{117, "Uus"},
-{118, "Uuo"},
+{110, "Ds"},
+{111, "Rg"},
+{112, "Cn"},
+{113, "Nh"},
+{114, "Fl"},
+{115, "Mc"},
+{116, "Lv"},
+{117, "Ts"},
+{118, "Og"},
 {0,"fin"}
 };
 
@@ -305,6 +305,15 @@ void Molec::printnorm(std::ostream & o)const{
   if (!iswater() && !iselectron() && t != aqueous) o << "_"  << moltypeStr[t];
 }
 
+/**
+ * Affiche le coefficient stœchimétrique
+ * @param o un flux de sortie
+ * @param sign plus ou moins un selon que c'est un produit ou un réactif.
+ **/
+void Molec::printcoeff(std::ostream & o, int sign)const{
+  o << nb * sign;
+}
+
 void Molec::coeff( fraction f){
   nb.i *= f.i;
   nb.d *= f.d;
@@ -558,6 +567,19 @@ void Membre::printnorm(std::ostream & o) const{
   }
 }
 
+/**
+ * affiche les coefficients stœchiométriques d'un membre d'équation
+ * @param o un flux de sortie
+ * @param sign la valeur plus ou moins un selon que les réactifs sont produits
+ *             ou consommés.
+ **/
+void Membre::printcoeff(std::ostream & o, int sign) const{
+  for(unsigned int i=0; i < size(); i++){
+    operator[](i)->printcoeff(o, sign);
+    if (i < size()-1) o << ",";
+  }
+}
+
 void Membre::printweight(std::ostream & o) const{
   for(unsigned int i=0; i < size(); i++){
     o << operator[](i)->weight();
@@ -747,6 +769,15 @@ void Chemeq::printnorm(std::ostream & o){
   }
 }
 
+/**
+ * Affiche les coefficients stœchiométriques
+ **/
+void Chemeq::printcoeff(std::ostream & o) const {
+  gauche->printcoeff(o, -1);
+  o << ";";
+  droit->printcoeff(o, 1);
+}
+
 void Chemeq::printcount(std::ostream & o) const {
   gauche->printcount(o);
   o << "; ";
